--AH:ScriptId=6DF30E11-5D1B-46C9-B15B-0DB08E79F068

CREATE TABLE [PackageContainerScanners]
(
	[PackageContainerScanner_Id] INT IDENTITY(1, 1) NOT NULL,
	[Configuration_Xml] XML NOT NULL,
	[LastScan_Date] DATETIME NULL,
	[LastScan_Status] CHAR(1) NULL,
	[LastScan_Error_Text] NVARCHAR(MAX) NULL,

	CONSTRAINT [PK__PackageContainerScanners]
		PRIMARY KEY ([PackageContainerScanner_Id]),

	CONSTRAINT [CK__PackageContainerScanners__LastScan_Status]
		CHECK ([LastScan_Status] IS NULL OR [LastScan_Status] IN ('S', 'W', 'E')),

	CONSTRAINT [CK__PackageContainerScanners__LastScan]
		CHECK (([LastScan_Date] IS NULL AND [LastScan_Status] IS NULL AND [LastScan_Error_Text] IS NULL)
		    OR ([LastScan_Date] IS NOT NULL AND [LastScan_Status] IS NOT NULL))
)
GO

CREATE TABLE [PackageUsage]
(
	[Package_Id] INT IDENTITY(1, 1) NOT NULL,
	[PackageContainerScanner_Id] INT NOT NULL,
	[Server_Name] NVARCHAR(100) NOT NULL,
	[PackageType_Name] VARCHAR(20) NOT NULL,
	[Package_Name] VARCHAR(200) NULL,
	[Package_Version] VARCHAR(200) NULL,
	[Details_Url] VARCHAR(256) NULL,
	[PackageStatus_Code] CHAR(1) NOT NULL,
	[Updated_Date] DATETIME NOT NULL,
	[Installed_Date] DATETIME NULL,
	[Removed_Date] DATETIME NULL,

	CONSTRAINT [PK__PackageUsage]
		PRIMARY KEY ([Package_Id]),

	CONSTRAINT [FK__PackageUsage__PackageContainerScanners]
		FOREIGN KEY ([PackageContainerScanner_Id])
		REFERENCES [PackageContainerScanners] ([PackageContainerScanner_Id])
		ON DELETE CASCADE,

	CONSTRAINT [UQ__PackageUsage]
		UNIQUE ([PackageType_Name], [Package_Name], [Package_Version], [PackageContainerScanner_Id], [Server_Name]),

	CONSTRAINT [CK__PackageUsage__PackageStatus_Code]
		CHECK ([PackageStatus_Code] IN ('I', 'R'))
)
GO

CREATE TABLE [ContainerUsage]
(
	[Container_Id] INT IDENTITY(1, 1) NOT NULL,
	[PackageContainerScanner_Id] INT NOT NULL,
	[Server_Name] NVARCHAR(100) NOT NULL,
	[Container_Name] VARCHAR(200) NOT NULL,
	[Image_Id] VARCHAR(128) NOT NULL,
	[Details_Url] VARCHAR(256) NULL,
	[ContainerStatus_Code] VARCHAR(16) NOT NULL,
	[Updated_Date] DATETIME NOT NULL,
	[Created_Date] DATETIME NOT NULL,

	CONSTRAINT [PK__ContainerUsage]
		PRIMARY KEY ([Container_Id]),

	CONSTRAINT [FK__ContainerUsage__PackageContainerScanners]
		FOREIGN KEY ([PackageContainerScanner_Id])
		REFERENCES [PackageContainerScanners] ([PackageContainerScanner_Id])
		ON DELETE CASCADE,

	CONSTRAINT [UQ__ContainerUsage]
		UNIQUE ([PackageContainerScanner_Id], [Server_Name], [Container_Name]),

	CONSTRAINT [CK__ContainerUsage__ContainerStatus_Code]
		CHECK ([ContainerStatus_Code] IN ('Running', 'Paused', 'Restarting', 'Dead', 'Created', 'Exited', 'Removed'))
)
GO

CREATE INDEX [IX__ContainerUsage__Image_Id]
	ON [ContainerUsage] ([Image_Id])
	INCLUDE ([PackageContainerScanner_Id])
